@@ -261,6 +261,24 @@ __NR_process_vm_readv = Constant("__NR_process_vm_readv", 270)
 __NR_process_vm_writev = Constant("__NR_process_vm_writev", 271)
 __NR_kcmp = Constant("__NR_kcmp", 272)
 __NR_finit_module = Constant("__NR_finit_module", 273)
+__NR_sched_setattr = Constant("__NR_sched_setattr", 274)
+__NR_sched_getattr = Constant("__NR_sched_getattr", 275)
+__NR_renameat2 = Constant("__NR_renameat2", 276)
+__NR_seccomp = Constant("__NR_seccomp", 277)
+__NR_getrandom = Constant("__NR_getrandom", 278)
+__NR_memfd_create = Constant("__NR_memfd_create", 279)
+__NR_bpf = Constant("__NR_bpf", 280)
+__NR_execveat = Constant("__NR_execveat", 281)
+__NR_userfaultfd = Constant("__NR_userfaultfd", 282)
+__NR_membarrier = Constant("__NR_membarrier", 283)
+__NR_mlock2 = Constant("__NR_mlock2", 284)
+__NR_copy_file_range = Constant("__NR_copy_file_range", 285)
+__NR_preadv2 = Constant("__NR_preadv2", 286)
+__NR_pwritev2 = Constant("__NR_pwritev2", 287)
+__NR_pkey_mprotect = Constant("__NR_pkey_mprotect", 288)
+__NR_pkey_alloc = Constant("__NR_pkey_alloc", 289)
+__NR_pkey_free = Constant("__NR_pkey_free", 290)
+__NR_statx = Constant("__NR_statx", 291)
 __NR_open = Constant("__NR_open", 1024)
 __NR_link = Constant("__NR_link", 1025)
 __NR_unlink = Constant("__NR_unlink", 1026)
