@@ -12,6 +12,11 @@ injecting our own code into the program space to track this.
 
 from __future__ import annotations
 
+from typing import Dict
+from typing import List
+from typing import Set
+from typing import Tuple
+
 import gdb
 
 import pwndbg.color.message as message
@@ -78,30 +83,30 @@ class RelocTypes:
 
 # Set of all type codes associated with jump slots, by architecture.
 JUMP_SLOTS = {
-    "x86-64": set([RelocTypes.R_X86_64_JUMP_SLOT]),
-    "i386": set([RelocTypes.R_386_JMP_SLOT]),
-    "aarch64": set([RelocTypes.R_AARCH64_JUMP_SLOT]),
-    "mips": set([RelocTypes.R_MIPS_JUMP_SLOT]),
-    "powerpc": set([RelocTypes.R_PPC_JMP_SLOT]),
-    "sparc": set([RelocTypes.R_SPARC_JMP_SLOT]),
-    "arm": set([RelocTypes.R_ARM_JUMP_SLOT]),
-    "armcm": set([RelocTypes.R_ARM_JUMP_SLOT]),
-    "rv32": set([RelocTypes.R_RISCV_JUMP_SLOT]),
-    "rv64": set([RelocTypes.R_RISCV_JUMP_SLOT]),
+    "x86-64": {RelocTypes.R_X86_64_JUMP_SLOT},
+    "i386": {RelocTypes.R_386_JMP_SLOT},
+    "aarch64": {RelocTypes.R_AARCH64_JUMP_SLOT},
+    "mips": {RelocTypes.R_MIPS_JUMP_SLOT},
+    "powerpc": {RelocTypes.R_PPC_JMP_SLOT},
+    "sparc": {RelocTypes.R_SPARC_JMP_SLOT},
+    "arm": {RelocTypes.R_ARM_JUMP_SLOT},
+    "armcm": {RelocTypes.R_ARM_JUMP_SLOT},
+    "rv32": {RelocTypes.R_RISCV_JUMP_SLOT},
+    "rv64": {RelocTypes.R_RISCV_JUMP_SLOT},
 }
 
 # Set of all type codes associated with irelative jump slots, by architecture.
 IRELATIVE_SLOTS = {
-    "x86-64": set([RelocTypes.R_X86_64_IRELATIVE]),
-    "i386": set([RelocTypes.R_386_IRELATIVE]),
-    "aarch64": set([RelocTypes.R_AARCH64_P32_IRELATIVE, RelocTypes.R_AARCH64_IRELATIVE]),
-    "mips": set([]),
-    "powerpc": set([RelocTypes.R_PPC_IRELATIVE]),
-    "sparc": set([RelocTypes.R_SPARC_IRELATIVE]),
-    "arm": set([RelocTypes.R_ARM_IRELATIVE]),
-    "armcm": set([RelocTypes.R_ARM_IRELATIVE]),
-    "rv32": set([RelocTypes.R_RISCV_IRELATIVE]),
-    "rv64": set([RelocTypes.R_RISCV_IRELATIVE]),
+    "x86-64": {RelocTypes.R_X86_64_IRELATIVE},
+    "i386": {RelocTypes.R_386_IRELATIVE},
+    "aarch64": {RelocTypes.R_AARCH64_P32_IRELATIVE, RelocTypes.R_AARCH64_IRELATIVE},
+    "mips": set(),
+    "powerpc": {RelocTypes.R_PPC_IRELATIVE},
+    "sparc": {RelocTypes.R_SPARC_IRELATIVE},
+    "arm": {RelocTypes.R_ARM_IRELATIVE},
+    "armcm": {RelocTypes.R_ARM_IRELATIVE},
+    "rv32": {RelocTypes.R_RISCV_IRELATIVE},
+    "rv64": {RelocTypes.R_RISCV_IRELATIVE},
 }
 
 
@@ -122,17 +127,17 @@ class TrapAllocator:
     block_capacity = 4096
     slot_size = 8
 
-    def __init__(self):
+    def __init__(self) -> None:
         self._reset()
 
-    def _reset(self):
+    def _reset(self) -> None:
         """
         Reset the internal state of the allocator.
         """
-        self.blocks = []
+        self.blocks: List[int] = []
         self.current_block_occupancy = 0
-        self.vacant_slots = []
-        self.occupied_slots = set()
+        self.vacant_slots: List[int] = []
+        self.occupied_slots: Set[int] = set()
 
     def alloc(self):
         """
@@ -172,7 +177,7 @@ class TrapAllocator:
         self.occupied_slots.add(addr)
         return addr
 
-    def free(self, address):
+    def free(self, address) -> None:
         """
         Indicates that an address obtained from alloc() can be recycled.
         """
@@ -188,12 +193,10 @@ class TrapAllocator:
         while len(self.blocks) > 0:
             block = self.blocks.pop()
             result = pwndbg.gdblib.shellcode.exec_syscall(
-                "SYS_munmap", block, self.block_capacity * self.slot_size, disable_breakpoints=True
+                "SYS_munmap", block, size, disable_breakpoints=True
             )
             if result != 0:
-                raise RuntimeError(
-                    f"SYS_munmap({block:#x}, {self.block_capacity * self.slot_size:#x}) failed ({result:#x})"
-                )
+                raise RuntimeError(f"SYS_munmap({block:#x}, {size:#x}) failed ({result:#x})")
         self._reset()
 
 
@@ -228,7 +231,7 @@ TRAP_ALLOCATOR = TrapAllocator()
 GOT_TRACKING = False
 
 # Map describing all of the currently installed analysis watchpoints.
-INSTALLED_WATCHPOINTS = {}
+INSTALLED_WATCHPOINTS: Dict[int, Tuple[Tracker, Patcher]] = {}
 
 
 class Patcher(pwndbg.gdblib.bpoint.Breakpoint):
@@ -242,7 +245,7 @@ class Patcher(pwndbg.gdblib.bpoint.Breakpoint):
     entry = 0
     tracker = None
 
-    def __init__(self, entry, tracker):
+    def __init__(self, entry, tracker) -> None:
         super().__init__(
             f"*(void**){entry:#x}", type=gdb.BP_WATCHPOINT, wp_class=gdb.WP_WRITE, internal=True
         )
@@ -266,7 +269,7 @@ class Patcher(pwndbg.gdblib.bpoint.Breakpoint):
             )
         )
 
-    def should_stop(self):
+    def should_stop(self) -> bool:
         # Read the new branch target, and update the redirection target of the
         # tracker accordingly.
         new_target = pwndbg.gdblib.memory.pvoid(self.entry)
@@ -303,7 +306,7 @@ class Tracker(pwndbg.gdblib.bpoint.Breakpoint):
     function together.
     """
 
-    hits = {}
+    hits: Dict[Tuple[int, ...], int] = {}
     total_hits = 0
     trapped_address = 0
 
@@ -313,17 +316,17 @@ class Tracker(pwndbg.gdblib.bpoint.Breakpoint):
     relocation_index = 0
     link_map_entry = None
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.trapped_address = TRAP_ALLOCATOR.alloc()
         super().__init__(f"*{self.trapped_address:#x}", internal=True)
         self.hits = {}
         self.silent = True
 
-    def delete(self):
+    def delete(self) -> None:
         TRAP_ALLOCATOR.free(self.trapped_address)
         super().delete()
 
-    def should_stop(self):
+    def should_stop(self) -> bool:
         # Notify the user about calls made through this GOT entry.
         print(f"[*] {self.sym_display_name}@{self.obj_display_name} called via GOT")
 
@@ -331,7 +334,7 @@ class Tracker(pwndbg.gdblib.bpoint.Breakpoint):
         stack = []
         frame = gdb.newest_frame().older()
         while frame is not None:
-            stack.append(frame.pc())
+            stack.append(int(frame.pc()))
             frame = frame.older()
         stack = tuple(stack)
         if stack not in self.hits:
@@ -344,7 +347,7 @@ class Tracker(pwndbg.gdblib.bpoint.Breakpoint):
         return False
 
 
-def _update_watchpoints():
+def _update_watchpoints() -> None:
     """
     Internal function responsible for updating the watchpoints that track the
     accesses to the GOT.
@@ -443,7 +446,7 @@ def tracked_entry_by_address(address):
     return INSTALLED_WATCHPOINTS.get(address)
 
 
-def enable_got_call_tracking(disable_hardware_whatchpoints=True):
+def enable_got_call_tracking(disable_hardware_whatchpoints=True) -> None:
     """
     Enable the analysis of calls made through the GOT.
     """
@@ -491,7 +494,7 @@ def enable_got_call_tracking(disable_hardware_whatchpoints=True):
     print("disabled and re-enabled in order to update the hooks.")
 
 
-def disable_got_call_tracking():
+def disable_got_call_tracking() -> None:
     """
     Disable the analysis of calls made through the GOT.
     """
